@@ -2,6 +2,7 @@ from typing import Optional
 from pydantic import Field
 from pystratis.core.types import Money
 from .federationmembermodel import FederationMemberModel
+from .miningstats import MiningStats
 
 
 class FederationMemberDetailedModel(FederationMemberModel):
@@ -24,3 +25,7 @@ class FederationMemberDetailedModel(FederationMemberModel):
     """The poll type."""
     reward_estimate_per_block: Optional[Money] = Field(alias='rewardEstimatePerBlock')
     """The reward estimate per block."""
+    federation_size: int = Field(alias='federationSize')
+    """The size of the federation."""
+    mining_stats: MiningStats = Field(alias='miningStats')
+    """The mining stats for the federation member."""
