@@ -5,8 +5,9 @@ from .memberipremoverequest import MemberIPRemoveRequest
 from .memberipreplacerequest import MemberIPReplaceRequest
 from .pendingtransferrequest import PendingTransferRequest
 from .verifytransferrequest import VerifyTransferRequest
+from .transferrequest import TransferRequest
 
 __all__ = [
     'DepositsRequest', 'FullySignedTransferRequest', 'MemberIPAddRequest', 'MemberIPRemoveRequest', 'MemberIPReplaceRequest',
-    'PendingTransferRequest', 'VerifyTransferRequest'
+    'PendingTransferRequest', 'VerifyTransferRequest', 'TransferRequest'
 ]
