@@ -5,3 +5,8 @@ from .federationmemberinfomodel import FederationMemberInfoModel
 from .maturedblockdepositsmodel import MaturedBlockDepositsModel
 from .serializableresult import SerializableResult
 from .validatetransactionresultmodel import ValidateTransactionResultModel
+
+__all__ = [
+    'CrossChainTransferModel', 'FederationGatewayInfoModel', 'FederationMemberConnectionInfoModel', 'FederationMemberInfoModel',
+    'MaturedBlockDepositsModel', 'SerializableResult', 'ValidateTransactionResultModel'
+]
