@@ -1,6 +1,7 @@
 from .pollsrequest import PollsRequest
 from .schedulevoteremovehashrequest import ScheduleVoteRemoveHashRequest
 from .schedulevotewhitelisthashrequest import ScheduleVoteWhitelistHashRequest
+from .schedulevotekickmemberrequest import ScheduleVoteKickMemberRequest
 from .votekey import VoteKey
 
-__all__ = ['PollsRequest', 'ScheduleVoteRemoveHashRequest', 'ScheduleVoteWhitelistHashRequest', 'VoteKey']
+__all__ = ['PollsRequest', 'ScheduleVoteRemoveHashRequest', 'ScheduleVoteWhitelistHashRequest', 'VoteKey', 'ScheduleVoteKickMemberRequest']
